The CellGraph class
CellGraph-class.RdThe CellGraph class is designed to hold information needed for working with PNA single-cell graphs.

CellGraph-class.RdThe CellGraph class is designed to hold information needed for working with PNA single-cell graphs.