Compute LCC sizes from downsampled edgelists
lcc_sizes.RdCalculates the sizes of the largest connected components (LCCs) from a set of parquet files containing downsampled edgelists.
Arguments
- df
A tibble with columns:
- pq_files
Paths to parquet files containing downsampled edgelists.
- fracs
The corresponding downsampling fractions.
Typically generated with
downsample_to_parquet.- mc_cores
Number of cores to use for parallel processing. Default is 1 (sequential processing). Values > 1 use
parallel::mclapply.
Value
A tibble with columns:
- component
The component (cell) identifier.
- frac
The downsampling fraction.
- n_nodes
The number of nodes in the largest connected component.
Details
See also
downsample_to_parquet for generating the input parquet files.
lcc_curve for a high-level wrapper.