Compute partition counts
partition_counts.RdCompute partition counts
Arguments
- cg
A CellGraph object containing the cell graph and count data.
- partition
A character or factor vector indicating the partition of nodes into groups. Either
partitionorpartition_columnmust be provided.- partition_column
A string indicating the name of the vertex attribute in the cell graph that contains the partition information.